@@ -20,7 +20,7 @@ For questions please check out http://pylib.org/contact.html
 from initpkg import initpkg
 trunk = None
 
-version = trunk or "1.0.0"
+version = trunk or "1.0.2"
 
 initpkg(__name__,
     description = "py.test and pylib: advanced testing tool and networking lib", 
@@ -52,7 +52,7 @@ initpkg(__name__,
     '_com.Registry'          : ('./_com.py', 'Registry'), 
     '_com.MultiCall'         : ('./_com.py', 'MultiCall'), 
     '_com.comregistry'       : ('./_com.py', 'comregistry'), 
-    '_com.Hooks'             : ('./_com.py', 'Hooks'), 
+    '_com.HookRelay'             : ('./_com.py', 'HookRelay'), 
 
     # py lib cmdline tools 
     'cmdline.pytest'         : ('./cmdline/pytest.py', 'main',),
