@@ -24,12 +24,20 @@ def checkprocess(script):
             cmd = script.basename
         else:
             cmd = "%s" %(script, )
+            # XXX distributed testing's rsync does not support
+            # syncing executable bits 
+            script.chmod(0777)
 
-        if script.basename.startswith("py.lookup"):
-            cmd += " hello"
+        if script.basename.startswith("py.lookup") or \
+           script.basename.startswith("py.which"):
+            cmd += " sys"
         print "executing", script
         try:
-            py.process.cmdexec(cmd)
+            old = script.dirpath().chdir()
+            try:
+                py.process.cmdexec(cmd)
+            finally:
+                old.chdir()
         except py.process.cmdexec.Error, e:
             if cmd.find("py.rest") != -1 and \
                e.out.find("module named") != -1:
@@ -46,10 +54,10 @@ def test_cmdline_namespace():
        
 def test_script_invocation():
     if iswin32:
-        for script in binwinpath.listdir("py.*"):
-            assert script.ext == ".cmd"
-            yield checkprocess, script 
+        scripts = binwinpath.listdir("py.*")
     else:
-        for script in binpath.listdir("py.*"):
-            yield checkprocess, script 
-
+        scripts = binpath.listdir("py.*")
+    scripts = [x for x in scripts 
+                if not x.basename.startswith("py.svnwcrevert")]
+    for script in scripts:
+        yield checkprocess, script 
